pub struct ResourceType(/* private fields */);Expand description
A set of bitflags which can be used to specify what resource to process into the cache.
For example, specifying [CHANNEL] but not [MESSAGE] will cache
created channels, channel updates, and channel deletes, but not their
messages.
Implementations
Sourceimpl ResourceType
impl ResourceType
Sourcepub const CHANNEL: ResourceType
pub const CHANNEL: ResourceType
Information relating to channels.
Sourcepub const EMOJI: ResourceType
pub const EMOJI: ResourceType
Information relating to emojis.
Sourcepub const GUILD: ResourceType
pub const GUILD: ResourceType
Information relating to guilds.
Sourcepub const MEMBER: ResourceType
pub const MEMBER: ResourceType
Information relating to members.
Sourcepub const MESSAGE: ResourceType
pub const MESSAGE: ResourceType
Information relating to messages.
Sourcepub const PRESENCE: ResourceType
pub const PRESENCE: ResourceType
Information relating to presences.
Sourcepub const REACTION: ResourceType
pub const REACTION: ResourceType
Information relating to reactions.
Sourcepub const ROLE: ResourceType
pub const ROLE: ResourceType
Information relating to roles.
Sourcepub const USER_CURRENT: ResourceType
pub const USER_CURRENT: ResourceType
Information relating the current user.
Sourcepub const USER: ResourceType
pub const USER: ResourceType
Information relating to users.
Sourcepub const VOICE_STATE: ResourceType
pub const VOICE_STATE: ResourceType
Information relating to voice states.
Sourcepub const STAGE_INSTANCE: ResourceType
pub const STAGE_INSTANCE: ResourceType
Information relating to stage instances.
Sourcepub const INTEGRATION: ResourceType
pub const INTEGRATION: ResourceType
Information relating to guild integrations.
Sourcepub const STICKER: ResourceType
pub const STICKER: ResourceType
Information relating to guild stickers.
Sourcepub const GUILD_SCHEDULED_EVENT: ResourceType
pub const GUILD_SCHEDULED_EVENT: ResourceType
Information relating to guild scheduled events.
Sourceimpl ResourceType
impl ResourceType
Sourcepub const fn empty() -> ResourceType
pub const fn empty() -> ResourceType
Get a flags value with all bits unset.
Sourcepub const fn all() -> ResourceType
pub const fn all() -> ResourceType
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<ResourceType>
pub const fn from_bits(bits: u64) -> Option<ResourceType>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> ResourceType
pub const fn from_bits_truncate(bits: u64) -> ResourceType
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> ResourceType
pub const fn from_bits_retain(bits: u64) -> ResourceType
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<ResourceType>
pub fn from_name(name: &str) -> Option<ResourceType>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: ResourceType) -> bool
pub const fn intersects(&self, other: ResourceType) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: ResourceType) -> bool
pub const fn contains(&self, other: ResourceType) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: ResourceType)
pub fn insert(&mut self, other: ResourceType)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: ResourceType)
pub fn remove(&mut self, other: ResourceType)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: ResourceType)
pub fn toggle(&mut self, other: ResourceType)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: ResourceType, value: bool)
pub fn set(&mut self, other: ResourceType, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: ResourceType) -> ResourceType
pub const fn intersection(self, other: ResourceType) -> ResourceType
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: ResourceType) -> ResourceType
pub const fn union(self, other: ResourceType) -> ResourceType
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: ResourceType) -> ResourceType
pub const fn difference(self, other: ResourceType) -> ResourceType
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: ResourceType) -> ResourceType
pub const fn symmetric_difference(self, other: ResourceType) -> ResourceType
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> ResourceType
pub const fn complement(self) -> ResourceType
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl ResourceType
impl ResourceType
Sourcepub const fn iter(&self) -> Iter<ResourceType>
pub const fn iter(&self) -> Iter<ResourceType>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ResourceType>
pub const fn iter_names(&self) -> IterNames<ResourceType>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.